@@ -1,5 +1,6 @@
 # FedData Tester
 library(FedData)
+library(magrittr)
 
 # Set a directory for testing
 testDir <- "~/FedData Test"
@@ -17,7 +18,17 @@ vepPolygon <- polygon_from_extent(raster::extent(672800,740000,4102000,4170000),
 NED <- get_ned(template=vepPolygon,
                label="VEPIIN")
 # Plot with raster::plot
-plot(NED)
+raster::plot(NED)
+
+
+# Get the DAYMET (North America only)
+# Returns a raster
+DAYMET <- get_daymet(template=vepPolygon,
+               label="VEPIIN",
+               elements = c("prcp","tmax"),
+               years = 1980:1985)
+# Plot with raster::plot
+raster::plot(DAYMET$tmax$X1985.10.23)
 
 
 # Get the daily GHCN data (GLOBAL)
@@ -26,35 +37,35 @@ plot(NED)
 GHCN.prcp <- get_ghcn_daily(template=vepPolygon, 
                             label="VEPIIN", 
                             elements=c('prcp'))
+# Plot the NED again
+raster::plot(NED)
 # Plot the spatial locations
-plot(GHCN.prcp$spatial, pch=1, add=T)
+sp::plot(GHCN.prcp$spatial, pch=1, add=T)
 legend('bottomleft', pch=1, legend="GHCN Precipitation Records")
 
 # Elements for which you require the same data
 # (i.e., minimum and maximum temperature for the same days)
 # can be standardized using standardize==T
-GHCN.temp <- get_ghcn_daily(template=vepPolygon, 
-                            label="VEPIIN", 
-                            elements=c('tmin','tmax'), 
-                            standardize=T)
+GHCN.temp <- get_ghcn_daily(template = vepPolygon, 
+                            label = "VEPIIN", 
+                            elements = c('tmin','tmax'), 
+                            years = 1980:1985,
+                            standardize = T)
 # Plot the NED again
 raster::plot(NED)
 # Plot the spatial locations
-plot(GHCN.temp$spatial, add=T, pch=1)
+sp::plot(GHCN.temp$spatial, add=T, pch=1)
 legend('bottomleft', pch=1, legend="GHCN Temperature Records")
 
 
 # Get the NHD (USA ONLY)
 NHD <- get_nhd(template=vepPolygon, 
-               label="VEPIIN",
-               force.redo = T)
+               label="VEPIIN")
 # Plot the NED again
 raster::plot(NED)
 # Plot the NHD data
-plot(NHD$NHDFlowline, add=T)
-plot(NHD$NHDLine, add=T)
-plot(NHD$NHDArea, col='black', add=T)
-plot(NHD$NHDWaterbody, col='black', add=T)
+NHD %>%
+  lapply(sp::plot, col='black', add=T)
 
 # Get the NRCS SSURGO data (USA ONLY)
 SSURGO.VEPIIN <- get_ssurgo(template=vepPolygon, 
@@ -66,22 +77,22 @@ plot(SSURGO.VEPIIN$spatial,
      lwd=0.1,
      add=T)
 
-# Or, download by Soil Survey Area names
-SSURGO.areas <- get_ssurgo(template=c("CO670","CO075"), 
-                     label="CO_TEST")
+# # Or, download by Soil Survey Area names
+# SSURGO.areas <- get_ssurgo(template=c("CO670","CO075"), 
+#                      label="CO_TEST")
 
-# Let's just look at spatial data for CO675
-SSURGO.areas.CO675 <- SSURGO.areas$spatial[SSURGO.areas$spatial$AREASYMBOL=="CO075",]
-
-# And get the NED data under them for pretty plotting
-NED.CO675 <- get_ned(template=SSURGO.areas.CO675,
-                     label="SSURGO_CO675")
-
-# Plot the SSURGO mapunit polygons, but only for CO675
-plot(NED.CO675)
-plot(SSURGO.areas.CO675,
-     lwd=0.1,
-     add=T)
+# # Let's just look at spatial data for CO675
+# SSURGO.areas.CO675 <- SSURGO.areas$spatial[SSURGO.areas$spatial$AREASYMBOL=="CO075",]
+# 
+# # And get the NED data under them for pretty plotting
+# NED.CO675 <- get_ned(template=SSURGO.areas.CO675,
+#                      label="SSURGO_CO675")
+# 
+# # Plot the SSURGO mapunit polygons, but only for CO675
+# plot(NED.CO675)
+# plot(SSURGO.areas.CO675,
+#      lwd=0.1,
+#      add=T)
 
 
 # Get the ITRDB records
